@@ -69,6 +69,11 @@ Excel options:
                                If the list is all integers, its interpreted as the zero-based
                                index of all the date columns for date processing.
                                [default: date,time,due,open,close,created]
+    --date-format <format>     Optional date format to use when formatting dates.
+                               See https://docs.rs/chrono/latest/chrono/format/strftime/index.html
+                               for the full list of supported formats.
+                               Note that if a date format is invalid, qsv will fall back and
+                               return the date as if no date-format was specified.
 
      --range <range>           An Excel format range, like C:T or C3:T25, to extract to the CSV.
 
@@ -78,7 +83,7 @@ Common options:
     -Q, --quiet                Do not display export summary message.
 "#;
 
-use std::{cmp, path::PathBuf};
+use std::{cmp, fmt::Write, path::PathBuf};
 
 use calamine::{open_workbook_auto, DataType, Range, Reader};
 use itertools::Itertools;
@@ -98,6 +103,7 @@ struct Args {
     flag_dates_whitelist: String,
     flag_output:          Option<String>,
     flag_quiet:           bool,
+    flag_date_format:     Option<String>,
     flag_range:           String,
 }
 
@@ -494,6 +500,13 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let mut float_flag: bool;
     let mut row_count = 0_usize;
 
+    let date_format = if let Some(df) = args.flag_date_format {
+        df
+    } else {
+        String::new()
+    };
+    let mut work_date;
+
     info!("exporting sheet ({sheet})...");
     for (row_idx, row) in range.rows().enumerate() {
         record.clear();
@@ -566,23 +579,44 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             // automatically process a cell as a date, even if its column is NOT in the whitelist
             if float_flag {
                 if cell_date_flag {
-                    if float_val.fract() > 0.0 {
-                        record.push_field({
-                            &cell.as_datetime().map_or_else(
-                                || format!("ERROR: Cannot convert {float_val} to datetime"),
-                                |dt| format!("{dt}"),
-                            )
-                        });
+                    work_date = if float_val.fract() > 0.0 {
+                        if let Some(dt) = cell.as_datetime() {
+                            if date_format.is_empty() {
+                                // no date format specified, so we'll just use the default
+                                // format for the datetime
+                                dt.to_string()
+                            } else {
+                                // a date format was specified, so we'll use it
+                                let mut formatted = String::new();
+                                if write!(formatted, "{}", dt.format(&date_format)).is_err() {
+                                    // if there was a format error, revert to the default format
+                                    formatted = dt.to_string();
+                                }
+                                formatted
+                            }
+                        } else {
+                            format!("ERROR: Cannot convert {float_val} to datetime")
+                        }
+                    } else if let Some(d) = cell.as_date() {
+                        if date_format.is_empty() {
+                            d.to_string()
+                        } else {
+                            let mut formatted = String::new();
+                            if write!(formatted, "{}", d.format(&date_format)).is_err() {
+                                formatted = d.to_string();
+                            }
+                            formatted
+                        }
                     } else {
-                        record.push_field({
-                            &cell.as_date().map_or_else(
-                                || format!("ERROR: Cannot convert {float_val} to date"),
-                                |d| format!("{d}"),
-                            )
-                        });
+                        format!("ERROR: Cannot convert {float_val} to date")
                     };
+                    record.push_field(&work_date);
+                } else if float_val.fract() > 0.0 {
+                    let mut buffer = ryu::Buffer::new();
+                    record.push_field(buffer.format_finite(float_val));
                 } else {
-                    record.push_field(&float_val.to_string());
+                    let mut buffer = itoa::Buffer::new();
+                    record.push_field(buffer.format(float_val as i64));
                 }
             }
         }
