@@ -45,6 +45,10 @@ struct Args {
 pub fn run(argv: &[&str]) -> CliResult<()> {
     let args: Args = util::get_args(USAGE, argv)?;
 
+    if args.arg_input.to_lowercase().ends_with(".sz") {
+        return fail_clierror!("Cannot index an a snappy file.");
+    }
+
     let pidx = match args.flag_output {
         None => util::idx_path(Path::new(&args.arg_input)),
         Some(p) => PathBuf::from(&p),
