@@ -8,7 +8,6 @@ pub mod behead;
 pub mod cat;
 pub mod count;
 pub mod dedup;
-#[cfg(feature = "feature_capable")]
 pub mod diff;
 #[cfg(any(feature = "feature_capable", feature = "lite"))]
 pub mod enumerate;
@@ -64,6 +63,7 @@ pub mod search;
 pub mod searchset;
 pub mod select;
 pub mod slice;
+pub mod snappy;
 pub mod sniff;
 pub mod sort;
 pub mod sortcheck;
