@@ -1,4 +1,4 @@
-#[cfg(any(feature = "full", feature = "lite"))]
+#[cfg(any(feature = "feature_capable", feature = "lite"))]
 use std::borrow::Cow;
 use std::{
     env, fs,
@@ -7,11 +7,11 @@ use std::{
 };
 
 use docopt::Docopt;
-#[cfg(any(feature = "full", feature = "lite"))]
+#[cfg(any(feature = "feature_capable", feature = "lite"))]
 use indicatif::{HumanCount, ProgressBar, ProgressStyle};
 use once_cell::sync::OnceCell;
 use serde::de::DeserializeOwned;
-#[cfg(any(feature = "full", feature = "lite"))]
+#[cfg(any(feature = "feature_capable", feature = "lite"))]
 use serde::de::{Deserialize, Deserializer, Error};
 use sysinfo::{System, SystemExt};
 
@@ -148,7 +148,7 @@ pub fn version() -> String {
     // setting and is only enforced when qsv is running in "non-streaming" mode (i.e. needs to
     // load the entire file into memory).
     let max_file_size = mem_file_check(Path::new(""), true, false).unwrap_or(0) as u64;
-    let mut sys = System::new();
+    let mut sys = System::new_with_specifics(sysinfo::RefreshKind::new().with_memory());
     sys.refresh_memory();
     let avail_mem = sys.available_memory();
     let total_mem = sys.total_memory();
@@ -253,7 +253,7 @@ pub fn count_rows(conf: &Config) -> Result<u64, CliError> {
     }
 }
 
-#[cfg(any(feature = "full", feature = "lite"))]
+#[cfg(any(feature = "feature_capable", feature = "lite"))]
 pub fn prep_progress(progress: &ProgressBar, record_count: u64) {
     progress.set_style(
         ProgressStyle::default_bar()
@@ -268,7 +268,7 @@ pub fn prep_progress(progress: &ProgressBar, record_count: u64) {
     log::info!("Progress started... {record_count} records");
 }
 
-#[cfg(any(feature = "full", feature = "lite"))]
+#[cfg(any(feature = "feature_capable", feature = "lite"))]
 pub fn finish_progress(progress: &ProgressBar) {
     progress.set_style(
         ProgressStyle::default_bar()
@@ -402,11 +402,11 @@ pub fn mem_file_check(path: &Path, version_check: bool, no_memcheck: bool) -> Re
 
     let no_memcheck_work = env::var("QSV_NO_MEMORY_CHECK").is_ok() || no_memcheck;
 
-    let mut sys = System::new();
+    let mut sys = System::new_with_specifics(sysinfo::RefreshKind::new().with_memory());
     sys.refresh_memory();
-    let total_mem = sys.total_memory();
     let avail_mem = sys.available_memory();
     let free_swap = sys.free_swap();
+    let total_mem = sys.total_memory();
     let mut mem_pct = env::var("QSV_FREEMEMORY_HEADROOM_PCT")
         .unwrap_or_else(|_| DEFAULT_FREEMEMORY_HEADROOM_PCT.to_string())
         .parse::<u8>()
@@ -450,7 +450,7 @@ pub fn mem_file_check(path: &Path, version_check: bool, no_memcheck: bool) -> Re
     Ok(max_avail_mem as i64)
 }
 
-#[cfg(any(feature = "full", feature = "lite"))]
+#[cfg(any(feature = "feature_capable", feature = "lite"))]
 pub fn condense(val: Cow<[u8]>, n: Option<usize>) -> Cow<[u8]> {
     match n {
         None => val,
@@ -518,7 +518,7 @@ pub fn range(start: Idx, end: Idx, len: Idx, index: Idx) -> Result<(usize, usize
 
 /// Create a directory recursively, avoiding the race conditions fixed by
 /// https://github.com/rust-lang/rust/pull/39799.
-#[cfg(any(feature = "full", feature = "lite"))]
+#[cfg(any(feature = "feature_capable", feature = "lite"))]
 fn create_dir_all_threadsafe(path: &Path) -> std::io::Result<()> {
     use std::thread;
 
@@ -542,14 +542,14 @@ fn create_dir_all_threadsafe(path: &Path) -> std::io::Result<()> {
 
 /// Represents a filename template of the form `"{}.csv"`, where `"{}"` is
 /// the place to insert the part of the filename generated by `qsv`.
-#[cfg(any(feature = "full", feature = "lite"))]
+#[cfg(any(feature = "feature_capable", feature = "lite"))]
 #[derive(Clone)]
 pub struct FilenameTemplate {
     prefix: String,
     suffix: String,
 }
 
-#[cfg(any(feature = "full", feature = "lite"))]
+#[cfg(any(feature = "feature_capable", feature = "lite"))]
 impl FilenameTemplate {
     /// Generate a new filename using `unique_value` to replace the `"{}"`
     /// in the template.
@@ -582,7 +582,7 @@ impl FilenameTemplate {
     }
 }
 
-#[cfg(any(feature = "full", feature = "lite"))]
+#[cfg(any(feature = "feature_capable", feature = "lite"))]
 impl<'de> Deserialize<'de> for FilenameTemplate {
     fn deserialize<D: Deserializer<'de>>(d: D) -> Result<FilenameTemplate, D::Error> {
         let raw = String::deserialize(d)?;
@@ -600,13 +600,18 @@ impl<'de> Deserialize<'de> for FilenameTemplate {
     }
 }
 
-pub fn init_logger() -> String {
+pub fn init_logger() -> (String, flexi_logger::LoggerHandle) {
     use flexi_logger::{Cleanup, Criterion, FileSpec, Logger, Naming};
 
     let qsv_log_env = env::var("QSV_LOG_LEVEL").unwrap_or_else(|_| "off".to_string());
     let qsv_log_dir = env::var("QSV_LOG_DIR").unwrap_or_else(|_| ".".to_string());
+    let write_mode = if env::var("QSV_LOG_UNBUFFERED").is_ok() {
+        flexi_logger::WriteMode::Direct
+    } else {
+        flexi_logger::WriteMode::BufferAndFlush
+    };
 
-    Logger::try_with_env_or_str(qsv_log_env)
+    let logger = Logger::try_with_env_or_str(qsv_log_env)
         .unwrap()
         .use_utc()
         .log_to_file(
@@ -614,6 +619,7 @@ pub fn init_logger() -> String {
                 .directory(qsv_log_dir)
                 .suppress_timestamp(),
         )
+        .write_mode(write_mode)
         .format_for_files(flexi_logger::detailed_format)
         .o_append(true)
         .rotate(
@@ -630,7 +636,7 @@ pub fn init_logger() -> String {
         String::new()
     };
     log::info!("START: {qsv_args}");
-    qsv_args
+    (qsv_args, logger)
 }
 
 #[cfg(feature = "self_update")]
