@@ -42,7 +42,6 @@ mod test_combos;
 mod test_comments;
 mod test_count;
 mod test_dedup;
-#[cfg(feature = "feature_capable")]
 mod test_diff;
 #[cfg(any(feature = "feature_capable", feature = "lite"))]
 mod test_enumerate;
@@ -94,6 +93,7 @@ mod test_search;
 mod test_searchset;
 mod test_select;
 mod test_slice;
+mod test_snappy;
 mod test_sniff;
 mod test_sort;
 mod test_sortcheck;
